@@ -192,6 +192,17 @@ applet_change_background (PanelApplet               *applet,
 			  GdkPixmap                 *pixmap,
 			  TasklistData              *tasklist)
 {
+	switch (type) {
+	case PANEL_NO_BACKGROUND:
+		wnck_tasklist_set_button_relief (WNCK_TASKLIST (tasklist->tasklist),
+						 GTK_RELIEF_NORMAL);
+		break;
+	case PANEL_COLOR_BACKGROUND:
+	case PANEL_PIXMAP_BACKGROUND:
+		wnck_tasklist_set_button_relief (WNCK_TASKLIST (tasklist->tasklist),
+						 GTK_RELIEF_NONE);
+		break;
+	}
 	wncklet_change_background (GTK_WIDGET (tasklist->applet), type,
 				   color, pixmap);
 }
@@ -774,7 +785,7 @@ display_about_dialog (BonoboUIComponent *uic,
 	wncklet_display_about (tasklist->applet, &tasklist->about,
 			       _("Window List"),
 			       "Copyright \xc2\xa9 2001-2002 Red Hat, Inc.",
-			       _("The Window List shows a list of all windows and lets you browse them."),
+			       _("The Window List shows a list of all windows in a set of buttons and lets you browse them."),
 			       authors,
 			       documenters,
 			       translator_credits,
